@@ -6,7 +6,7 @@
 #
 # LLNL-CODE-797170
 # All rights reserved.
-# This file is part of Merlin, Version: 1.5.0.
+# This file is part of Merlin, Version: 1.5.1.
 #
 # For details, see https://github.com/LLNL/merlin.
 #
@@ -106,6 +106,9 @@ def decrypt(payload):
     return f.decrypt(payload)
 
 
-# initialize the key to disk on import to prevent race conditions later on, or at least drastically reduce
-# the number of corner cases where they could appear.
-Fernet(_get_key())
+def init_key():
+    """
+    Initialize the key to disk on import to prevent race conditions later on, or at least drastically reduce
+    the number of corner cases where they could appear.
+    """
+    Fernet(_get_key())
